@@ -62,10 +62,10 @@ def usage() :
     print "-d                  Remove duplicate masses from labeling"
     print "-e                  Use theoretical mass"
     print "-f    fasta_file    Fasta file to relate peptides to their proteins (this is optional)."
-    print "-g    mass_modifs   List of allowed fragment mass modifications. Useful for phosphorylation and neutral losses. Example: -g -80,-98,-17,-18"
+    print "-g    mass_modifs   List of allowed fragment mass modifications. Useful for phosphorylation and neutral losses. Example: -g -79.97,-97.98,-17.03,-18.01"
     print "-i    labeling_file File containing the amino acid isotopic labeling mass shifts. If this option is used, heavy transitions will be generated."
     print "-k    output_key    Select the output provided. Keys available: openswath, peakview. Default: peakview"
-    print "-l    mass_limits   Lower and Upper mass limits. Example: -l 400,1200"
+    print "-l    mass_limits   Lower and upper mass limits of fragment ions. Example: -l 400,2000"
     print "-m    mods_file     File with the modifications delta mass"
     print "-n    int           Max number of reported ions per peptide/z. Default: 20"
     print "-o    int           Min number of reported ions per peptide/z. Default: 3"
@@ -73,7 +73,7 @@ def usage() :
     print "-q    int            Number of processors to use (only for isoforms!). Default: 1"
     print "-s    ion_series    List of ion series to be used. Example: -s y,b"
     print "-t    time-scale    Options: minutes, seconds. Default: seconds."
-    print "-u     unimod-code    Use this unimod code as a switching modification. Useful for phosphorilations. Example: -u 21"
+    print "-u     unimod-code    Use this unimod code as a switching modification. Useful for phosphorylations. Example: -u 21"
     print "-v                  Verbose mode."
     print "-w    swaths_file   File containing the swath ranges. This is used to remove transitions with Q3 falling in the swath mass range. (line breaks in windows/unix format)"
     print "-x    allowed_frg_z Fragment ion charge states allowed. Default: 1,2"
@@ -356,10 +356,10 @@ def isoform_writer(isobaric_species, lock, sptxtfile, modLibrary, aaLib, searchE
             peaks = []
             if spectrum : 
                 z_parent = float(spectrum.name.split('/')[1])
-                if spectrum.RetTime_detected != -1 :
-                    RT_experimental = spectrum.RetTime_detected / 60.0   #PeakView expect minutes, and spectraST reports seconds.
-                if spectrum.iRT_detected != -1 :
-                    iRT_experimental = spectrum.iRT_detected / 60.0   #PeakView expect minutes, and spectraST reports seconds.
+                if spectrum.RetTime_detected:
+                    RT_experimental = spectrum.RetTime / 60.0   #PeakView expect minutes, and spectraST reports seconds.
+                if spectrum.iRT_detected:
+                    iRT_experimental = spectrum.iRT / 60.0   #PeakView expect minutes, and spectraST reports seconds.
                 else:
                     iRT_experimental = RT_experimental
                 if not useMinutes : iRT_experimental = iRT_experimental * 60
@@ -539,10 +539,10 @@ def transitions_isobaric_peptides(isobaric_species , sptxtfile, switchingModific
             peaks = []
             if spectrum : 
                 z_parent = float(spectrum.name.split('/')[1])
-                if spectrum.RetTime_detected != -1 :
-                    RT_experimental = spectrum.RetTime_detected / 60.0   #PeakView expect minutes, and spectraST reports seconds.
-                if spectrum.iRT_detected != -1 :
-                    iRT_experimental = spectrum.iRT_detected / 60.0   #PeakView expect minutes, and spectraST reports seconds.
+                if spectrum.RetTime_detected:
+                    RT_experimental = spectrum.RetTime / 60.0   #PeakView expect minutes, and spectraST reports seconds.
+                if spectrum.iRT_detected:
+                    iRT_experimental = spectrum.iRT / 60.0   #PeakView expect minutes, and spectraST reports seconds.
                 else:
                     iRT_experimental = RT_experimental
                 if not useMinutes : iRT_experimental = iRT_experimental * 60
@@ -871,10 +871,10 @@ def main(argv) :
             
             iRT_experimental = 0.0
             RT_experimental = 0.0
-            if spectrum.RetTime_detected != -1 :
-                RT_experimental = spectrum.RetTime_detected / 60.0   #PeakView expect minutes, and spectraST reports seconds.
-            if spectrum.iRT_detected != -1 :
-                iRT_experimental = spectrum.iRT_detected / 60.0   #PeakView expect minutes, and spectraST reports seconds.
+            if spectrum.RetTime_detected:
+                RT_experimental = spectrum.RetTime / 60.0   #PeakView expect minutes, and spectraST reports seconds.
+            if spectrum.iRT_detected:
+                iRT_experimental = spectrum.iRT / 60.0   #PeakView expect minutes, and spectraST reports seconds.
             else:
                 iRT_experimental = RT_experimental
 
@@ -1000,8 +1000,12 @@ def main(argv) :
 
             #Sort transitions by frg_serie, frg_nr, frg_z and MINUS intensity, then remove duplicates
             #this means of every frag_serie/no/chg only the highest(!) intensity peak is stored
-            filteredtransitions = sorted(filteredtransitions, key= lambda x: (x[9], x[10], x[11], -x[5]))
-            filteredtransitions = removeDuplicates(filteredtransitions, lambda x: (x[9], x[10], x[11]))
+            if key == 'peakview':
+                filteredtransitions = sorted(filteredtransitions, key=lambda x: (x[9], x[10], x[11], -x[5]))
+                filteredtransitions = removeDuplicates(filteredtransitions, lambda x: (x[9], x[10], x[11]))
+            elif key == 'openswath':
+                filteredtransitions = sorted(filteredtransitions, key=lambda x: (x[15], x[16], x[17], -x[5]))
+                filteredtransitions = removeDuplicates(filteredtransitions, lambda x: (x[15], x[16], x[17]))
 
             #REVERSE sort the transitions by intensity
             #this means the highest(!) intensity peaks of this transition are on top
@@ -1046,10 +1050,10 @@ def main(argv) :
                         precursorMZ_heavy      = heavy_transition[0]
                         fragment_mz_heavy      = heavy_transition[1]
                         sequence_heavy         = heavy_transition[8]
-                        z_parent               = heavy_transition[15]
-                        frg_serie              = heavy_transition[18]
-                        frg_z                   = heavy_transition[19]
-                        frg_number               = heavy_transition[20]
+                        z_parent               = heavy_transition[12]
+                        frg_serie              = heavy_transition[15]
+                        frg_z                   = heavy_transition[16]
+                        frg_number               = heavy_transition[17]
                                         
                     #NOTE: This only works for y- and b- ions (AND their neutral losses). Other fragment series are ignored, and no heavy transition will be generated for them.
                     if frg_serie[0] not in ['y','b'] : continue
@@ -1105,8 +1109,12 @@ def do_filtering_and_write(filteredtransitions, writer, labeling, removeDuplicat
     #Sort transitions by frg_serie, frg_nr, frg_z and MINUS intensity, then remove duplicates
     #this means of every frag_serie/no/chg only the highest(!) intensity peak is stored
     if verbose : print "initial number transitions " , len(filteredtransitions)
-    filteredtransitions = sorted(filteredtransitions, key= lambda x: (x[9], x[10], x[11], -x[5]))
-    filteredtransitions = removeDuplicates(filteredtransitions, lambda x: (x[9], x[10], x[11]))
+    if key == 'peakview':
+        filteredtransitions = sorted(filteredtransitions, key=lambda x: (x[9], x[10], x[11], -x[5]))
+        filteredtransitions = removeDuplicates(filteredtransitions, lambda x: (x[9], x[10], x[11]))
+    elif key == 'openswath':
+        filteredtransitions = sorted(filteredtransitions, key=lambda x: (x[15], x[16], x[17], -x[5]))
+        filteredtransitions = removeDuplicates(filteredtransitions, lambda x: (x[15], x[16], x[17]))
     if verbose : print "after removing duplicates " , len(filteredtransitions)
 
     #REVERSE sort the transitions by intensity
@@ -1157,10 +1165,10 @@ def do_filtering_and_write(filteredtransitions, writer, labeling, removeDuplicat
                 precursorMZ_heavy      = heavy_transition[0]
                 fragment_mz_heavy      = heavy_transition[1]
                 sequence_heavy         = heavy_transition[8]
-                z_parent               = heavy_transition[15]
-                frg_serie              = heavy_transition[18]
-                frg_z                   = heavy_transition[19]
-                frg_number               = heavy_transition[20]
+                z_parent               = heavy_transition[12]
+                frg_serie              = heavy_transition[15]
+                frg_z                   = heavy_transition[16]
+                frg_number               = heavy_transition[17]
                                 
             #NOTE: This only works for y- and b- ions (AND their neutral losses). Other fragment series are ignored, and no heavy transition will be generated for them.
             if frg_serie[0] not in ['y','b'] : continue
