@@ -289,9 +289,12 @@ class GeneralPrecursor(PrecursorBase):
           return selected[0]
         else: 
             return None
+
+    def get_all_peakgroups(self):
+        return self.peakgroups
   
     def find_closest_in_iRT(self, delta_assay_rt):
-      return min(self.peakgroups , key=lambda x: abs(float(x.get_normalized_retentiontime()) - float(delta_assay_rt)))
+      return min(self.peakgroups, key=lambda x: abs(float(x.get_normalized_retentiontime()) - float(delta_assay_rt)))
 
 class Precursor(PrecursorBase):
     """
@@ -507,7 +510,6 @@ class SWATHScoringReader:
       skipped = 0; read = 0
       runs = []
       for file_nr, f in enumerate(self.infiles):
-
         if verbosity >= 10:
             stdout.write("\rReading %s" % str(f))
             stdout.flush()
@@ -517,10 +519,7 @@ class SWATHScoringReader:
             filehandler = gzip.open(f,'rb')
         else:
             filehandler = open(f)
-
         reader = csv.reader(filehandler, delimiter="\t")
-        # Up to here we use up 0.00191187858582s
-
         header = reader.next()
         for i,n in enumerate(header):
           header_dict[n] = i
@@ -531,16 +530,11 @@ class SWATHScoringReader:
         # Check if runs are already aligned (only one input file and correct header)
         already_aligned = (len(self.infiles) == 1 and header_dict.has_key(self.aligned_run_id_name))
 
-        # Up to here we use up 0.00189304351807s
-
         for this_row in reader:
-            # Up to here we use up 42.9 seconds -> csv library seems to use up a lot of the time (also with gzip)
-            # can we do something faster here? pandas?
             if already_aligned:
-                runid = this_row[ header_dict[self.aligned_run_id_name] ]
+                runid = this_row[header_dict[self.aligned_run_id_name]]
             else:
-                runnr = this_row[ header_dict[self.run_id_name] ]
-                #runnr = this_row[ run_id_col ]
+                runnr = this_row[header_dict[self.run_id_name]]
                 runid = runnr + "_" + str(file_nr)
 
             current_run = [r for r in runs if r.get_id() == runid]
@@ -565,7 +559,6 @@ class SWATHScoringReader:
             read += 1
             # Unfortunately, since we are using csv, tell() will not work...
             # print "parse row at", filehandler.tell()
-            # Up to here we use up 43.9 seconds
             self.parse_row(current_run, this_row, read_exp_RT)
 
       # Here we check that each run indeed has a unique id
